@@ -31,6 +31,8 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#include <handy.h>
+
 #include "screenshot-application.h"
 #include "screenshot-area-selection.h"
 #include "screenshot-config.h"
@@ -810,6 +812,8 @@ screenshot_application_startup (GApplication *app)
 
   G_APPLICATION_CLASS (screenshot_application_parent_class)->startup (app);
 
+  hdy_init ();
+
   screenshot_load_config ();
 
   g_set_application_name (_("Screenshot"));
